@@ -5,7 +5,7 @@
  * vector, which will subsequently be passed to the main() function;
  * provides a _setargv() hook, similar to that described on MSDN.
  *
- * $Id: setargv.c,v d92e16a7179a 2018/04/16 14:53:36 keith $
+ * $Id: setargv.c,v e1250ad8c571 2018/09/06 18:50:09 keith $
  *
  * Written by Keith Marshall <keithmarshall@users.sourceforge.net>
  * Copyright (C) 2014, 2017, 2018, MinGW.org Project
@@ -93,7 +93,7 @@ void __mingw32_setargv( const char *cmdline )
 {
   /* Implementation of the MinGW replacement command line interpreter.
    */
-  char cmdbuf[1 + strlen( cmdline ) << 1];
+  char cmdbuf[(1 + strlen( cmdline )) << 1];
   int c, gotarg = 0, quoted = 0, bracket = 0, bslash = 0;
   char *argptr = cmdbuf; const char *cmdptr = cmdline;
   glob_t gl_argv;
@@ -111,7 +111,7 @@ void __mingw32_setargv( const char *cmdline )
 
   /* Scan the command line, and prepare it for globbing.
    */
-  while( c = *cmdptr++ )
+  while( (c = *cmdptr++) != '\0' )
   {
     /* Got a character to process...
      */
